@@ -87,7 +87,7 @@ sub uncheck {
 }
 
 sub click {
-    my ($self, $locator, $wait) = @_;
+    my ($self, $locator) = @_;
 
     my $element = $self->resolve_locator($locator);
 
@@ -99,28 +99,25 @@ sub click {
     if ($tag eq 'input' and ($type eq 'checkbox' or $type eq 'radio')) {
         $element->property_search('click()');
     }
+    elsif (($tag eq 'input' and ($type eq 'submit' or $type eq 'image'))
+        or $tag eq 'submit'
+        or ($tag eq 'button' and $type eq 'submit')) {
+
+        $element->property_search('click()');
+        $self->wait_for_condition(sub {
+            $self->load_status eq 'started'
+        }, 100);
+    }
     else {
         $element->fire_event('click');
     }
 
-    if ($wait) {
-        $self->wait_for_condition(sub {
-            $self->is_loading;
-        }, $wait);
-    }
 
     $self->process_page_load;
 
     return 1;
 }
 
-sub click_and_wait {
-    my ($self, $locator, $timeout) = @_;
-
-    $timeout //= $self->default_timeout;
-    return $self->click($locator, $timeout);
-}
-
 sub left_click {
     my ($self) = @_;
 
